from setuptools import find_packages, setup

setup(
  name = '5o4drel5mk',
  packages=find_packages(),
  version = '0.1',
  description = '',
  author = '',
  author_email = '',
  url = '',
  keywords = [],
  classifiers = [],
)